@@ -7,6 +7,7 @@ and generates PyTorch model accordingly.
 - Contact: lim.jeikei@gmail.com
 """
 
+import inspect
 from typing import Callable, Dict, List, Optional, Tuple, Type, Union
 
 import numpy as np
@@ -17,7 +18,9 @@ from torch import nn
 from kindle.generator.base_generator import GeneratorAbstract, ModuleGenerator
 from kindle.generator.flatten import FlattenGenerator
 from kindle.generator.yolo_head import YOLOHeadGenerator
+from kindle.modules import Conv, DWConv, Focus, YOLOHead
 from kindle.utils.model_utils import ModelInfoLogger, ModelProfiler
+from kindle.utils.torch_utils import fuse_conv_and_batch_norm
 
 
 class Model(nn.Module):
@@ -25,7 +28,7 @@ class Model(nn.Module):
 
     def __init__(
         self,
-        cfg: Union[str, Dict[str, Type]],
+        cfg: Union[str, Dict[str, type]],
         verbose: bool = False,
     ) -> None:
         """Parse model from the model config file.
@@ -84,6 +87,75 @@ class Model(nn.Module):
 
         return y
 
+    def export(
+        self, export_activations=("SiLU", "Hardswish", "Mish"), verbose: bool = False
+    ) -> nn.Module:
+        """Make model to export friendly version.
+
+        This method will call export() method in every child modules,
+        convert activations into export-friendly version,
+        and fuse conv-batch_norm itself.
+
+        Args:
+            export_activations: Activation name list to convert themselves
+                into export-friendly version.
+            verbose: print logs
+
+        Return:
+            self
+        """
+        self.fuse(verbose=verbose)
+        for module in self.model.modules():
+            if hasattr(module, "export") and inspect.ismethod(module.export):
+                # Check if the module has export method
+                if verbose:
+                    print(f"Calling {module.name} export()")
+                module.export()  # type: ignore
+
+            if hasattr(module, "activation"):
+                for activation in export_activations:
+                    if hasattr(nn, activation) and isinstance(
+                        module.activation, getattr(nn, activation)
+                    ):
+                        if verbose:
+                            print(
+                                f"Converting {module.activation} activation"
+                                f" in {module.__class__.__name__} to export friendly version."
+                            )
+                        module.activation = getattr(
+                            __import__("kindle.modules.activation", fromlist=[""]),
+                            activation,
+                        )()
+                        break
+
+        return self
+
+    def fuse(self, verbose: bool = False) -> nn.Module:
+        """Fuse Conv - BatchNorm2d layers."""
+
+        if verbose:
+            print("Fusing layers ", end="")
+
+        for module in self.model.modules():
+            dot_str = "."
+
+            if isinstance(module, (Conv, DWConv, Focus)) and hasattr(
+                module, "batch_norm"
+            ):
+                module.conv = fuse_conv_and_batch_norm(module.conv, module.batch_norm)
+                delattr(module, "batch_norm")
+                module.forward = module.fuseforward  # type: ignore
+
+                dot_str = ","
+
+            if verbose:
+                print(dot_str, end="", flush=True)
+
+        if verbose:
+            print(" Done!")
+
+        return self
+
     def profile(self, verbose: bool = True, **kwargs) -> ModelProfiler:
         """Run model profiler.
 
@@ -120,6 +192,56 @@ class Model(nn.Module):
         return x
 
 
+class YOLOModel(Model):
+    """YOLO model."""
+
+    def __init__(
+        self,
+        cfg: Union[str, Dict[str, type]],
+        verbose: bool = False,
+        init_bias=False,
+        **kwargs,
+    ) -> None:
+        """Parse YOLOModel from the model config file.
+
+        Args:
+            cfg: yaml file path or dictionary type of the model.
+            verbose: print the model parsing information.
+            init_bias: Initialize bias.
+            kwargs: Keyword arguments for the YOLOHead.initialize_biases
+        """
+        super().__init__(cfg, verbose=verbose)
+
+        assert isinstance(self.model[-1], YOLOHead), (
+            "YOLOHead must have YOLOHead at the end! "
+            f"Current last layer: {self.model[-1].name} "
+        )
+
+        self._yolo_init()
+        self.initialize_biases = self.model[-1].initialize_biases
+
+        if init_bias:
+            self.initialize_biases(**kwargs)
+
+        # YOLOv5 compatability
+        self.stride = self.model[-1].stride
+
+    def _yolo_init(self) -> None:
+        """Initialize model for YOLO training."""
+
+        # Initialize batch norm
+        for module in self.model.modules():
+            module_type = type(module)
+
+            if module_type is nn.Conv2d:
+                pass
+            elif module_type is nn.BatchNorm2d:
+                module.eps = 1e-3  # type: ignore
+                module.momentum = 0.03  # type: ignore
+            elif module_type in (nn.LeakyReLU, nn.ReLU, nn.ReLU6):
+                module.inplace = True  # type: ignore
+
+
 class ModelParser:
     """Generate PyTorch model from the model yaml file."""
 
