@@ -2,18 +2,21 @@
 
 from kindle.modules.activation import Activation
 from kindle.modules.add import Add
-from kindle.modules.bottleneck import Bottleneck, BottleneckCSP
+from kindle.modules.bottleneck import C3, Bottleneck, BottleneckCSP, MV2Block
 from kindle.modules.concat import Concat
 from kindle.modules.conv import Conv, Focus
 from kindle.modules.dwconv import DWConv
 from kindle.modules.linear import Linear
-from kindle.modules.poolings import SPP, GlobalAvgPool
+from kindle.modules.mobilevit import MobileViTBlock
+from kindle.modules.poolings import SPP, SPPF, GlobalAvgPool
 from kindle.modules.yolo_head import YOLOHead
 
 __all__ = [
     "Add",
     "Bottleneck",
     "BottleneckCSP",
+    "C3",
+    "MV2Block",
     "Concat",
     "Conv",
     "DWConv",
@@ -21,6 +24,8 @@ __all__ = [
     "Linear",
     "GlobalAvgPool",
     "SPP",
+    "SPPF",
     "Activation",
     "YOLOHead",
+    "MobileViTBlock",
 ]
