@@ -8,7 +8,7 @@ from typing import Union
 import torch
 from torch import nn
 
-from kindle.torch_utils import Activation
+from kindle.modules.activation import Activation
 
 
 class Linear(nn.Module):
@@ -17,7 +17,9 @@ class Linear(nn.Module):
     Arguments: [channel, activation]
     """
 
-    def __init__(self, in_channel: int, out_channel: int, activation: Union[str, None]):
+    def __init__(
+        self, in_channels: int, out_channels: int, activation: Union[str, None]
+    ):
         """
 
         Args:
@@ -27,7 +29,7 @@ class Linear(nn.Module):
                 which is no activation.
         """
         super().__init__()
-        self.linear = nn.Linear(in_channel, out_channel)
+        self.linear = nn.Linear(in_channels, out_channels)
         self.activation = Activation(activation)()
 
     def forward(self, x: torch.Tensor) -> torch.Tensor:
